Install imbalanced_ensemble — imbalanced-ensemble 0.1.0 documentation

# Install imbalanced_ensemble

## Prerequisites

The following packages are requirements:

> - `numpy`

> - `scipy`

> - `pandas`

> - `joblib`

> - `sklearn`

> - `matplotlib`

> - `seaborn`

## Installation

### Install from PyPi

You can install imbalanced-ensemble from PyPI by running:

    > pip install imbalanced-ensemble

### Clone from GitHub

Or you can install imbalanced-ensemble locally:

    > git clone https://github.com/ZhiningLiu1998/imbalanced-ensemble.git
    > cd imbalanced-ensemble
    > pip install .